@@ -90,7 +90,9 @@ class DaskGatewaySlurmConfig(sinfo.SInfoTable):
         for sinfo_row in self.rows:
             label = f"P: {sinfo_row.queue}, I: {sinfo_row.ec2_instance_type}, CPU: {sinfo_row.vcpu}, Mem: {sinfo_row.mem}"
             memory = sinfo_row.mem / sinfo_row.vcpu
-            memory = in(DataSize(f"{sinfo_row.mem - 1}Gi"))
+            # Using all of the available memory is very error prone
+            # instead use 95%
+            memory = int(DataSize(f"{sinfo_row.mem - 1}Gi"))
             profiles[label] = {
                 "worker_cores": sinfo_row.vcpu,
                 "scheduler_cores": sinfo_row.vcpu,
